package com.tidefactions.chat.Utils;

import com.tidefactions.chat.Config;
import com.tidefactions.chat.Events.MessageSendInChannelEvent;
import com.tidefactions.chat.Types.ChatMode;
import com.tidefactions.chat.Types.Prefix;
import org.bukkit.Bukkit;
import org.bukkit.Sound;
import org.bukkit.entity.Player;

import java.util.HashMap;
import java.util.UUID;

public class ChatUtils {

    private static HashMap<UUID, ChatMode> currentChatMode = new HashMap<>();

    public static void sendMessageInChannel(Player player, ChatMode mode, String message, String source) {
        String finalMessage = getMessageForChannel(player, mode, message);
        MessageSendInChannelEvent event = new MessageSendInChannelEvent(player.getName(), mode, message, source);
        Bukkit.getPluginManager().callEvent(event);
        Bukkit.broadcast(finalMessage, mode.getPermission());
        if (message.contains("@")) {
            String[] array = message.split(" ");
            for (String word : array)
                if (word.startsWith("@")) {
                    Player mentioned = Bukkit.getPlayer(word.replace("@", ""));
                    if (mentioned != null)
                        mentioned.playSound(mentioned.getLocation(), Sound.ORB_PICKUP, 1, 0);
                }
        }
    }

    public static void sendMessageInChannelAsConsole(ChatMode mode, String message, String source) {
        String finalMessage = getMessageForChannelAsConsole(mode, message);
        MessageSendInChannelEvent event = new MessageSendInChannelEvent("CONSOLE", mode, message, source);
        Bukkit.getPluginManager().callEvent(event);
        Bukkit.broadcast(finalMessage, mode.getPermission());
    }

    public static String getMessageForChannel(Player player, ChatMode mode, String message) {
        Prefix prefix = PrefixUtils.getPrefixForPlayer(player);
        return mode.getFormat()
                .replaceAll("<MODE_PREFIX>", mode.getPrefix())
                .replaceAll("<PREFIX>", prefix.getPrefix())
                .replaceAll("<PLAYER_NAME>", player.getName())
                .replaceAll("<TITLE>", TitleUtils.getTitleForPlayer(player))
                .replaceAll("<CHAT_COLOR>", prefix.getChatColor().toString())
                .replaceAll("<MESSAGE>", message);
    }

    public static String getMessageForChannelAsConsole(ChatMode mode, String message) {
        return mode.getFormat()
                .replaceAll("<MODE_PREFIX>", mode.getPrefix())
                .replaceAll("<PREFIX>", Config.CONSOLE_PREFIX)
                .replaceAll("<PLAYER_NAME>", "CONSOLE")
                .replaceAll("<TITLE>", Config.CONSOLE_TITLE)
                .replaceAll("<CHAT_COLOR>", Config.CONSOLE_CHAT_COLOR)
                .replaceAll("<MESSAGE>", message);
    }

    public static void setChatMode(Player player, ChatMode mode) {
        currentChatMode.put(player.getUniqueId(), mode);
    }

    public static ChatMode getChatMode(Player player) {
        return currentChatMode.getOrDefault(player.getUniqueId(), ChatMode.PUBLIC);
    }
}
