package com.tidefactions.chat.Utils;

import com.tidefactions.chat.Databases.PrefixDatabase;
import com.tidefactions.chat.Main;
import com.tidefactions.chat.Types.Prefix;
import org.bukkit.ChatColor;
import org.bukkit.Material;
import org.bukkit.configuration.InvalidConfigurationException;
import org.bukkit.configuration.file.YamlConfiguration;
import org.bukkit.entity.Player;

import java.io.File;
import java.io.IOException;
import java.util.Collection;
import java.util.HashMap;

import static com.tidefactions.chat.Main.logger;

public class PrefixUtils {

    private static HashMap<String, Prefix> prefixes = new HashMap<>();

    public static void loadPrefixes(File prefixFile) {
        if (!prefixFile.getParentFile().exists())
            prefixFile.getParentFile().mkdirs();
        if (!prefixFile.exists())
            Main.ExportResource("/prefixes.yml", prefixFile);
        try {
            YamlConfiguration config = new YamlConfiguration();
            config.load(prefixFile);
            for (String key : config.getKeys(false)) {
                prefixes.put(key, new Prefix(
                        key,
                        config.getString(key + ".permission"),
                        ChatColor.translateAlternateColorCodes('&', config.getString(key + ".prefix")),
                        Material.getMaterial(config.getString(key + ".item")),
                        config.getInt(key + ".item-meta"),
                        config.getStringList(key + ".description"),
                        ChatColor.valueOf(config.getString(key + ".chat-color"))
                ));
                logger.info("Loaded prefix: " + key);
            }
        } catch (IOException | InvalidConfigurationException e) {
            e.printStackTrace();
        }

    }

    public static Prefix getPrefixForPlayer(Player player) {
        return prefixes.getOrDefault(PrefixDatabase.getPrefixIDForPlayer(player), prefixes.get("Default"));
    }

    public static void setPrefixForPlayer(Player player, Prefix prefix) {
        PrefixDatabase.setPrefix(player, prefix);
    }

    public static Prefix getPrefixByID(String id) {
        return prefixes.get(id.replaceAll(ChatColor.BLACK.toString(), ""));
    }

    public static Collection<Prefix> getPrefixes() {
        return prefixes.values();
    }
}
